@@ -4,6 +4,7 @@ import time
 from PIL import Image
 import xml.etree.ElementTree as ET
 from selenium import webdriver
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from gmapsbounds import constants
 
 def load_image(filename):
@@ -22,6 +23,10 @@ def parse_url(url):
 def launch_driver(url=''):
     driver = webdriver.Firefox()
     driver.maximize_window()
+    # dcap = dict(DesiredCapabilities.PHANTOMJS)
+    # dcap["phantomjs.page.settings.userAgent"] = constants.USER_AGENT
+    # driver = webdriver.PhantomJS(desired_capabilities=dcap)
+    # driver.set_window_size(1920, 1080)
     if url:
         driver.get(url)
     return driver
@@ -142,3 +147,16 @@ def write_to_kml(location_list, filename):
             add_placemark(root, location)
             with open('{}.kml'.format(os.path.join(filename, location.name)), 'w') as f:
                 f.write(ET.tostring(root).decode('utf8'))
+
+def same_line(start, end, test_node):
+	'''
+	Return whether test_node is approximately along the same line as
+	start and end nodes
+	'''
+	distance_ratio = get_distance(start, test_node) / get_distance(start, end)
+	xdiff, ydiff = end.x - start.x, end.y - start.y
+	expected_x, expected_y = start.x + distance_ratio * xdiff, start.y + distance_ratio * ydiff
+	if max(abs(expected_x - test_node.x), abs(expected_y - test_node.y)) >= 2:
+		return False
+	return True
+
